# Shopiuu API Python

#### Description
Shopiuu API Library for Python

#### Installation

pip install shopiuu-api

#### Instructions

Please browse the files in the example folder for usage examples.
